<?php
/*
Plugin Name: Custom logo wp-admin
Description: Cambia el logo del área de login de Wordpress y su enlace. Permite algunos ajustes básicos sobre el color del logo.
Author: Christian Cabrero
Author URI: https://cabrero.ch
Version: 3.2.0
License: GPLv2
Domain Path: /languages
Text Domain: wlw-plugins
*/

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

/* Customiza el logo de wp-admin */
function my_custom_login_logo(){
    $options = get_option('wlw_custom_logo_options');
    $logo_url = isset($options['logo_url']) ? $options['logo_url'] : '';
    $logo_invert = isset($options['logo_invert']) ? $options['logo_invert'] : '0';
	$logo_gris = isset($options['logo_gris']) ? $options['logo_gris'] : '1';
    echo '<style type="text/css">
        #login h1 a { 
            background-image: url(' . $logo_url . ') !important;
            background-size: contain !important;
            background-repeat: no-repeat !important;
            background-position: center center !important;
            width: 100% !important;
            height: 100px !important;
            display: block !important;
            margin: 0 auto !important;
            filter: invert(' . $logo_invert . ') !important;
        }
		#login h1{
			filter: brightness(' . $logo_gris . ') !important;
        }
        #login h1{
            padding-top: 20px;
            text-align: center;
        }
    </style>';
}


add_action('login_head', 'my_custom_login_logo');


add_filter('login_headerurl', 'custom_loginlogo_url');

function custom_loginlogo_url($url){
    return get_bloginfo('url');
}

// Añadir menú de administración

add_action('admin_menu', 'wlw_custom_logo_wp_admin_menu');

function wlw_custom_logo_wp_admin_menu(){
    add_menu_page(
        'Custom logo wp-admin', 
        'Custom logo wp-admin', 
        'administrator',   
        'wlw-custom-logo-wp-admin', 
        'wlw_custom_logo_render_settings_page', 
        'dashicons-format-image', 
        20 
    );
}

function wlw_custom_logo_render_settings_page() {
    ?>
  <div class="wrap">
      <h2>Custom logo wp-admin</h2>
      <form method="post" action="options.php">
          <?php settings_fields('wlw_custom_logo_options'); ?>
          <?php do_settings_sections('wlw-custom-logo-settings'); ?>
          <?php submit_button(); ?>
      </form>
  </div>
    <?php
}

function wlw_custom_logo_settings_fields() {
    add_settings_section(
        'wlw_custom_logo_section', // ID de la sección
        'Opciones', // Título de la sección
        'wlw_custom_logo_section_callback', // Callback para renderizar la sección
        'wlw-custom-logo-settings' // Página de configuración
    );

    add_settings_field(
        'wlw_custom_logo_url', // ID del campo
        'URL que reemplazará el logo de Wordpress:', // Título del campo
        'wlw_custom_logo_url_callback', // Callback para renderizar el campo
        'wlw-custom-logo-settings', // Página de configuración
        'wlw_custom_logo_section' // ID de la sección
    );

    add_settings_field(
      'wlw_custom_logo_invert', // ID del campo
      'Invertir color del logo:', // Título del campo
      'wlw_custom_logo_invert_callback', // Callback para renderizar el campo
      'wlw-custom-logo-settings', // Página de configuración
      'wlw_custom_logo_section' // ID de la sección
  );
	
	add_settings_field(
      'wlw_custom_logo_gris', // ID del campo
      'Logo de color negro:', // Título del campo
      'wlw_custom_logo_gris_callback', // Callback para renderizar el campo
      'wlw-custom-logo-settings', // Página de configuración
      'wlw_custom_logo_section' // ID de la sección
  );

    register_setting(
        'wlw_custom_logo_options', // Nombre del grupo de opciones
        'wlw_custom_logo_options' // Nombre de la opción
    );
}

function wlw_custom_logo_section_callback() {
	echo "";
}

function wlw_custom_logo_url_callback() {
    $options = get_option('wlw_custom_logo_options');
    $logo_url = isset($options['logo_url']) ? $options['logo_url'] : '';
    echo "<input type='text' name='wlw_custom_logo_options[logo_url]' value='$logo_url' size='100'/>";
}

function wlw_custom_logo_invert_callback() {
    $options = get_option('wlw_custom_logo_options');
    $logo_invert = isset($options['logo_invert']) ? $options['logo_invert'] : '';
    echo "<input type='checkbox' name='wlw_custom_logo_options[logo_invert]' value='1' " . checked(1, $logo_invert, false) . " />";
}


function wlw_custom_logo_gris_callback() {
    $options = get_option('wlw_custom_logo_options');
    $logo_gris = isset($options['logo_gris']) ? $options['logo_gris'] : '';
    echo "<input type='checkbox' name='wlw_custom_logo_options[logo_gris]' value='0' " . checked(0, $logo_gris, false) . " />";
}

add_action('admin_init', 'wlw_custom_logo_settings_fields');

register_uninstall_hook(__FILE__, 'wlw_custom_logo_uninstall');

function wlw_custom_logo_uninstall(){
    delete_option('wlw_custom_logo_options');
}